django-calaccess-raw-data
=========================

A Django app to download, extract and load campaign finance and lobbying
activity data from the California Secretary of State's
`CAL-ACCESS <http://www.sos.ca.gov/prd/cal-access/>`__ database

|Build Status| |PyPI version| |Coverage Status| |Documentation Status|

-  Documentation:
   `django-calaccess.californiacivicdata.org <http://django-calaccess.californiacivicdata.org>`__
-  Issues:
   `github.com/california-civic-data-coalition/django-calaccess-raw-data/issues <https://github.com/california-civic-data-coalition/django-calaccess-raw-data/issues>`__
-  Packaging:
   `pypi.python.org/pypi/django-calaccess-raw-data <https://pypi.python.org/pypi/django-calaccess-raw-data>`__
-  Testing:
   `travis-ci.org/california-civic-data-coalition/django-calaccess-raw-data <https://travis-ci.org/california-civic-data-coalition/django-calaccess-raw-data>`__
-  Coverage:
   `coveralls.io/r/california-civic-data-coalition/django-calaccess-raw-data <https://coveralls.io/r/california-civic-data-coalition/django-calaccess-raw-data>`__

.. |Build Status| image:: https://travis-ci.org/california-civic-data-coalition/django-calaccess-raw-data.png?branch=master
   :target: https://travis-ci.org/california-civic-data-coalition/django-calaccess-raw-data
.. |PyPI version| image:: https://badge.fury.io/py/django-calaccess-raw-data.png
   :target: http://badge.fury.io/py/django-calaccess-raw-data
.. |Coverage Status| image:: https://coveralls.io/repos/california-civic-data-coalition/django-calaccess-raw-data/badge.png?branch=master
   :target: https://coveralls.io/r/california-civic-data-coalition/django-calaccess-raw-data?branch=master
.. |Documentation Status| image:: https://readthedocs.org/projects/django-calaccess-raw-data/badge/?version=latest
   :target: https://django-calaccess-raw-data.readthedocs.org/